@@ -2,6 +2,7 @@ import logging
 
 from ..errors import InvalidRequestError
 from ..errors import UnauthorizedClientError
+from ..hooks import hooked
 from .base import BaseGrant
 from .base import TokenEndpointMixin
 
@@ -89,25 +90,26 @@ class ResourceOwnerPasswordCredentialsGrant(BaseGrant, TokenEndpointMixin):
 
         if not client.check_grant_type(self.GRANT_TYPE):
             raise UnauthorizedClientError(
-                f'The client is not authorized to use "grant_type={self.GRANT_TYPE}"'
+                f"The client is not authorized to use 'grant_type={self.GRANT_TYPE}'"
             )
 
         params = self.request.form
         if "username" not in params:
-            raise InvalidRequestError('Missing "username" in request.')
+            raise InvalidRequestError("Missing 'username' in request.")
         if "password" not in params:
-            raise InvalidRequestError('Missing "password" in request.')
+            raise InvalidRequestError("Missing 'password' in request.")
 
         log.debug("Authenticate user of %r", params["username"])
         user = self.authenticate_user(params["username"], params["password"])
         if not user:
             raise InvalidRequestError(
-                'Invalid "username" or "password" in request.',
+                "Invalid 'username' or 'password' in request.",
             )
         self.request.client = client
         self.request.user = user
         self.validate_requested_scope()
 
+    @hooked
     def create_token_response(self):
         """If the access token request is valid and authorized, the
         authorization server issues an access token and optional refresh
@@ -135,11 +137,10 @@ class ResourceOwnerPasswordCredentialsGrant(BaseGrant, TokenEndpointMixin):
         :returns: (status_code, body, headers)
         """
         user = self.request.user
-        scope = self.request.scope
+        scope = self.request.payload.scope
         token = self.generate_token(user=user, scope=scope)
         log.debug("Issue token %r to %r", token, self.client)
         self.save_token(token)
-        self.execute_hook("process_token", token=token)
         return 200, token, self.TOKEN_RESPONSE_HEADER
 
     def authenticate_user(self, username, password):
